==> gtktalog-0.1.0.tar.gz: gtktalog-0.1.0/src/plugins/mod.cpp <==
/***************************************************************************
                          main.cpp  -  description                              
                             -------------------                                         
    begin                : Tue Aug 17 11:57:10 CEST 1999
                                           
    copyright            : (C) 1999 by Attila Mszros                         
    email                : meszat@freemail.c3.hu                                    
    modified by          : Mathieu Villegas
    email                : gtktalog.iskewl.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include <iostream.h>
#include <stdlib.h>
#include <stdio.h>

void info()
{
  printf("MOD name extraction plugin\n 1999 (c) Attila Mszros <meszat@freemail.c3.hu>\n modified by Mathieu Villegas <gtktalog@caramail.com> from the original KADEmod program.\n");
}


void GetModName(FILE* file)
{
  char ret[20];
  fread(ret,20,1,file);
  printf("%s\n",ret);
}

int main(int argc, char** argv)
{
  char buff[1000];
  char* fname=buff;
  FILE *f;
  
  if ((!strcmp(argv[argc - 1],"--help"))||(argc == 1))
    {
      info();
      exit(0);
    }
  
  if ((f=fopen(argv[1],"r")) != NULL)
    {
      GetModName(f);
      fclose(f);
    }
}

==> gtktalog-0.10.1.tar.gz: gtktalog-0.10.1/src/plugins/mod.cpp <==
/***************************************************************************
                          main.cpp  -  description                              
                             -------------------                                         
    begin                : Tue Aug 17 11:57:10 CEST 1999
                                           
    copyright            : (C) 1999 by Attila Mszros                         
    email                : meszat@freemail.c3.hu                                    
    modified by          : Mathieu Villegas
    email                : gtktalog@caramail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include <iostream.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

void info()
{
  printf("MOD name extraction plugin\n 1999 (c) Attila Mszros <meszat@freemail.c3.hu>\n modified by Mathieu Villegas <gtktalog@caramail.com> from the original KADEmod program.\n");
}


void GetModName(FILE* file)
{
  char ret[20];
  fread(ret,20,1,file);
  printf("%s\n",ret);
}

int main(int argc, char** argv)
{
  char buff[1000];
  char* fname=buff;
  FILE *f;
  
  if ((!strcmp(argv[argc - 1],"--help"))||(argc == 1))
    {
      info();
      exit(0);
    }
  
  if ((f=fopen(argv[1],"r")) != NULL)
    {
      GetModName(f);
      fclose(f);
    }
}
